@@ -33,7 +33,7 @@ use Feature::Compat::Class;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 class Amazon::Sites {
   use Amazon::Site;
@@ -156,6 +156,26 @@ codes and the values are the corresponding ASIN URLs.
 
 1;
 
+=head1 COPYRIGHT
+
+Copyright 2024, Dave Cross. All rights reserved.
+
+=head1 LICENCE
+
+This program is free software; you can redistribute it and/or modify it under
+the terms of either:
+
+=over 4
+
+=item * the GNU General Public License as published by the Free Software
+Foundation; either version 1, or (at your option) any later version, or
+
+=item * the Artistic License version 2.0.
+
+=back
+
+=cut
+
 __DATA__
 AE UAE ae AED 1
 AU Australia com.au AUD 2
